/**
 * A reviver function for parsing JSON that transforms ISO 8601 date strings into Date objects.
 *
 * This matches on anything that has an ISO 8601 formatted date, but also matches if they include the time
 * portion of the pattern.
 *
 * Matches on:
 *  YYYY
 *  YYYY-MM
 *  YYYY-MM-DD
 *  YYYY-MM-DDThh:mmTZD
 *  YYYY-MM-DDThh:mm:ss
 *  YYYY-MM-DDThh:mm:ssTZD
 *  YYYY-MM-DDThh:mm:ss.s
 *  YYYY-MM-DDThh:mm:ss.sTZD
 * @see {@link https://www.w3.org/TR/NOTE-datetime}
 *
 * @param _ the key of the entry in the object being parsed
 * @param value the vlaue of the entry in the object being parsed
 * @returns a Date object, if the value matches an ISO 8601 pattern with a valid date, the original value otherwise
 */
export declare function JsonISO8601DateReviver(_: string, value: unknown): Date | unknown;
/**
 * A reviver function for parsing JSON that transforms ISO 8601 date and time strings into Date objects.
 *
 * This matches exclusively on ISO 8601 formatted strings that include the time portion of the pattern. If
 * no time is provided, this will return the original string.
 * Matches on:
 *  YYYY-MM-DDThh:mm:ss
 *  YYYY-MM-DDThh:mm:ssTZD
 *  YYYY-MM-DDThh:mm:ss.s
 *  YYYY-MM-DDThh:mm:ss.sTZD
 * @see {@link https://www.w3.org/TR/NOTE-datetime}
 *
 * @param _ the key of the entry in the object being parsed
 * @param value the vlaue of the entry in the object being parsed
 * @returns a Date object, if the value matches an ISO 8601 pattern with a valid date and time, the original value otherwise
 */
export declare function JsonISO8601DateAndTimeReviver(_: string, value: unknown): Date | unknown;
//# sourceMappingURL=Date.d.ts.map