import { MediaTypeCategory } from "../types/MediaTypeCategory.js";
import { NodeSupportedEncoding } from "../types/NodeSupportedEncoding.js";
/**
 * A content type handler that can provide WWW Form encoded bodies.
 *
 * Converts the payload (which should be a simple key value pair object) to URL encoding.
 */
const WWWFormEncodedContentTypeHandler = {
    mediaType: `${MediaTypeCategory.Application}/x-www-form-urlencoded`,
    charset: NodeSupportedEncoding.UTF8,
    get header() {
        return `${this.mediaType}; charset=${this.charset}`;
    },
    getContentForRequestFromPayload(payload) {
        const formBodyArray = [];
        for (const property in payload) {
            const encodedKey = encodeURIComponent(property);
            const rawValue = payload[property];
            const encodableValue = String(rawValue);
            const encodedValue = encodeURIComponent(encodableValue);
            formBodyArray.push(encodedKey + "=" + encodedValue);
        }
        return formBodyArray.join("&");
    },
};
export default WWWFormEncodedContentTypeHandler;
//# sourceMappingURL=WWWFormEncodedContentTypeHandler.js.map